/****************************************************************************
 *
 * $Id:
 *
 * Copyright (C) 1998-2006 Lasmea. All rights reserved.
 *
 * This software was developed at:
 * Institut Pascal- UMR 6602
 * 63 175 Aubière Cedex
 * http://ip.univ-bpclermont.fr
 *
 * This file may be distributed under the terms of the Q Public License
 * as defined by Trolltech AS of Norway and appearing in the file
 * LICENSE included in the packaging of this file.
 *
 * Licensees holding valid IPDS Professional Edition licenses may
 * use this file in accordance with the IPDS Commercial License
 * Agreement provided with the Software.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Contact . if any conditions of this licensing are
 * not clear to you.
 *
 *
 * Author: Jonathan Courbon - Hemanth Korrapati -
 *
 *****************************************************************************/

#include "containers.h"
#include "config.h"


#include <iostream>
#include <sstream>
#include <vector>
#include <string>
#include <stdio.h>
#include <string.h>

#if WITH_OPENCV == 1
  #include <cv.h>
  #include <highgui.h>
#else
  #include <opencv2/core/core.hpp>
  #include <opencv2/highgui/highgui.hpp>
#endif






void usage()
{
    std::cout << "============================" << std::endl;
    std::cout << "  Viewer Single Camera" << std::endl;
    std::cout << "============================" << std::endl;
    std::cout << "Usage: ./ViewerSingleCamera sequencePath sensorAlias" << std::endl;
    std::cout << "   The sensorAlias must be one of the following value: f-l-cam ,f-r-cam, b-cam, f-m-cam, fe-cam, webcam, cata-cam" << std::endl;
}



int main(int argc, char* argv[])
{

    
    if(argc>=3)
    {
      std::string sequencePath(argv[1]);
      std::string sensorAlias(argv[2]);
      

      if(strcmp(sensorAlias.c_str(),"f-l-cam")==0
            || strcmp(sensorAlias.c_str(),"f-r-cam")==0
            || strcmp(sensorAlias.c_str(),"b-cam")==0
            || strcmp(sensorAlias.c_str(),"f-m-cam")==0
            || strcmp(sensorAlias.c_str(),"fe-cam")==0
            || strcmp(sensorAlias.c_str(),"webcam")==0
            || strcmp(sensorAlias.c_str(),"cata-cam")==0)
      {
	

        long long int startingtime=-1;
        long long int endingtime=-1;
        std::vector<Unit> keyData;
  
           
	ConfigTable ctable;
	std::stringstream msg;
	msg << CONFIGFOLDERPATH << "/config_table";
	ctable.readTable(msg.str());
    

        TimestampInterval interval(startingtime,endingtime);
        std::string timestamps_file_name=ctable.table[sensorAlias].folderName+ctable.table[sensorAlias].suffix;
        std::string sensor_data_folder=sequencePath+"/"+ctable.table[sensorAlias].folderName+"/";
        getReadings(ctable.table[sensorAlias].sensorName, sensor_data_folder, timestamps_file_name, ctable.table[sensorAlias].tfm, keyData, interval,1);

        // get extensions
        std::string keyprefix=sequencePath+"/"+ctable.table[sensorAlias].folderName+"/"+ctable.table[sensorAlias].folderName+"-";
        std::string keysuffix=ctable.table[sensorAlias].params["extension"];

        std::cout << keyData.size() << " timestamps read from " << sensor_data_folder+timestamps_file_name << std::endl;
        std::cout << ctable.table[sensorAlias].folderName << " " << ctable.table[sensorAlias].suffix << std::endl;
	
	int milliseconds=(int)(1000./atof(ctable.table[sensorAlias].params["fps"].c_str()));
	
	
	unsigned int currentkeyindex=0;
	std::string filename;
	
	
	cv::Mat image;
	cv::namedWindow( "Display window", CV_WINDOW_AUTOSIZE );// Create a window for display.
	int keyPressed=-1;
	
	while(currentkeyindex<keyData.size())
	{
	  // get the image file name
	  ctable.getSensorFilePathFromIndex(sensorAlias,filename,keyData[currentkeyindex].index);
	  filename=sequencePath+ "/" + filename;
	  
	  // display it
	  image = cv::imread(filename, CV_LOAD_IMAGE_COLOR);   // Read the file

	  if(! image.data )                              // Check for invalid input
	  {
	      std::cout <<  "Could not open or find the image: "<< filename << std::endl ;
	  }
	  else
	  {
	    cv::imshow( "Display window", image );                   // Show our image inside it.
	    keyPressed=cv::waitKey(milliseconds); 
	  }

	  // ESCAPE key has been pressed
	  if(keyPressed==27)
	    break;
	  

	  // go to next image
	  currentkeyindex++;
	}
	    
	
      }
      else
      {
	  
	usage();
	
      }
      
      

    
    
    }
    else
    {
      usage();
      return 0;
    }
 


}
